@@ -1,10 +1,11 @@
 context("Correct mode selected")
 
 test_that("statamode selects the mode right for each method", {
-  expect_match(statamode("a"), "a")
-  expect_match(statamode(c("a", "a", "b", "b"), method="stata"), ".")
-  expect_match(statamode(c("a", "a", "b", "b"), method="last"), "b")
- # expect_match(statamode(c("a", "a", "b", "b"), method="sample"), c("a", "b"), all=FALSE)
+  expect_that(statamode("a"), matches("a"))
+  expect_that(statamode(c("a", "a", "b", "b"), method="stata"), matches("."))
+  expect_that(statamode(c("a", "a", "b", "b"), method="last"), matches("b"))
+  expect_that(statamode(c("b", "b", "a", "a"), method="last"), matches("a"))
+ # expect_that(statamode(c("a", "a", "b", "b"), method="sample"), matches(c("a", "b"),all=FALSE))
 })
 
 set.seed(100)
@@ -133,5 +134,4 @@ test_that("statamode handles all types of modes", {
         }
     }
   }
-})
-
+})
\ No newline at end of file
